@@ -5,11 +5,11 @@
 *             AFTER XmHTMLP.h as it references a number of structures defined
 *             in that header.
 *
-* This file Version	$Revision: 1.6 $
+* This file Version	$Revision: 1.7 $
 *
 * Creation date:		Tue Aug 19 16:03:22 GMT+0100 1997
-* Last modification: 	$Date: 1999/04/08 19:32:52 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1999/07/29 01:26:28 $
+* By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -35,11 +35,16 @@
 *
 *****/
 /*****
-* $Source: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/XmHTMLI.h,v $
+* $Source: /cvs/gnome/gnome-libs/gtk-xmhtml/Attic/XmHTMLI.h,v $
 *****/
 /*****
 * ChangeLog 
 * $Log: XmHTMLI.h,v $
+* Revision 1.7  1999/07/29 01:26:28  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.6  1999/04/08 19:32:52  unammx
 *
 *
@@ -1049,5 +1054,24 @@ extern void __XmHTMLBadParent(TWidget w, String func);
 extern void _XmHTMLAllocError(TWidget w, char *module, char *routine, 
 	char *func, int size);
 
+#include "gtk-xmhtml.h"
+#include "gtk-xmhtml-p.h"
+
+void gtk_xmhtml_set_outline (GtkXmHTML *html, int flag);
+void my_x_query_colors(GdkColormap *colormap,
+		       GdkColor    *colors,
+		       gint         ncolors);
+void
+gtk_xmhtml_set_colors (GtkXmHTML *html,
+		       Pixel foreground,
+		       Pixel background,
+		       Pixel anchor_fg,
+		       Pixel anchor_target_fg,
+		       Pixel anchor_visited_fg,
+		       Pixel anchor_activated_fg,
+		       Pixel anchor_activated_bg);
+
+void _XmHTMLRecomputeShadowColors(XmHTMLWidget html, Pixel base);
+
 /* Don't add anything after this endif! */
 #endif /* _XmHTMLI_h_ */
