@@ -1,14 +1,11 @@
-#ifndef lint
-static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/plc.c,v 1.9 1998/02/12 03:09:43 unammx Exp $";
-#endif
 /*****
 * plc.c : XmHTML Progressive Loader Context interfacing routines.
 *
-* This file Version	$Revision: 1.9 $
+* This file Version	$Revision: 1.10 $
 *
 * Creation date:		Thu Jun 12 16:46:34 GMT+0100 1997
-* Last modification: 	$Date: 1998/02/12 03:09:43 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1999/07/29 01:26:29 $
+* By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -38,6 +35,11 @@ static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/plc.c,
 /*****
 * ChangeLog 
 * $Log: plc.c,v $
+* Revision 1.10  1999/07/29 01:26:29  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.9  1998/02/12 03:09:43  unammx
 * Merge to Koen's XmHTML 1.1.2 + following fixes:
 *
